@@ -1,13 +1,15 @@
 package CGI::Session::Serialize::freezethaw;
 
-# freezethaw.pm,v 1.4 2005/02/09 08:30:53 sherzodr Exp 
+# freezethaw.pm,v 1.5 2005/02/17 03:20:34 sherzodr Exp 
 
 use strict;
 #use diagnostics;
 
 use FreezeThaw;
+use CGI::Session::ErrorHandler;
 
-$CGI::Session::Serialize::freezethaw::VERSION = '1.4';
+$CGI::Session::Serialize::freezethaw::VERSION = '1.5';
+@CGI::Session::Serialize::freezethaw::ISA     = qw( CGI::Session::ErrorHandler );
 
 sub freeze {
     my ($self, $data) = @_;
